@@ -44,7 +44,8 @@
 #include "nsIHttpChannel.h"
 #include "nsString.h"
 #include "nsNetUtil.h"
-#include "nsSpecialSystemDirectory.h"
+#include "nsDirectoryServiceUtils.h"
+#include "nsDirectoryServiceDefs.h"
 #include "nsReadableUtils.h"
 #include "nsNetCID.h"
 
@@ -95,7 +96,7 @@ nsIPCBuffer::nsIPCBuffer()
     mPipeWrite(IPC_NULL_HANDLE),
     mPipeRead(IPC_NULL_HANDLE),
 
-    mTempFileSpec(nsnull),
+    mTempFile(nsnull),
     mTempOutStream(nsnull),
     mTempInStream(nsnull),
 
@@ -317,7 +318,7 @@ nsIPCBuffer::OpenInputStream(nsIInputStream** result)
 
   mStreamOffset = 0;
 
-  if (mByteCount && mTempFileSpec) {
+  if (mByteCount && mTempFile) {
     rv = OpenTempInStream();
     if (NS_FAILED(rv))
       return rv;
@@ -332,27 +333,37 @@ nsIPCBuffer::OpenInputStream(nsIInputStream** result)
 NS_IMETHODIMP
 nsIPCBuffer::CreateTempFile()
 {
+  nsresult rv;
+
   DEBUG_LOG(("nsIPCBuffer::CreateTempFile: \n"));
 
-  if (mTempFileSpec)
+  if (mTempFile)
     return NS_ERROR_FAILURE;
 
-  mTempFileSpec = new nsFileSpec(nsSpecialSystemDirectory(nsSpecialSystemDirectory::OS_TemporaryDirectory));
+  nsCOMPtr<nsIProperties> directoryService =
+    do_GetService(NS_DIRECTORY_SERVICE_CONTRACTID, &rv);
+  directoryService->Get(NS_OS_TEMP_DIR, NS_GET_IID(nsIFile), getter_AddRefs(mTempFile));
 
-  if (!mTempFileSpec)
+  if (! mTempFile)
     return NS_ERROR_OUT_OF_MEMORY;
 
-  *mTempFileSpec += SAFE_TMP_FILENAME;
-  mTempFileSpec->MakeUnique();
+  mTempFile->AppendNative(nsDependentCString(SAFE_TMP_FILENAME));
+  if (NS_FAILED(mTempFile->CreateUnique(nsIFile::NORMAL_FILE_TYPE, 00600))) {
+    return NS_ERROR_FAILURE;
+  }
+
+  nsCAutoString nativePath;
+  mTempFile->GetNativePath(nativePath);
 
   DEBUG_LOG(("nsIPCBuffer::CreateTempFile: %s\n",
-             mTempFileSpec->GetNativePathCString()));
+            nativePath.get()));
 
-  mTempOutStream = new nsOutputFileStream(*mTempFileSpec,
-                            PR_WRONLY | PR_CREATE_FILE | PR_TRUNCATE, 00600);
+  mTempOutStream  = do_CreateInstance("@mozilla.org/network/file-output-stream;1", &rv);
+  if (NS_FAILED(rv)) return rv;
+
+  rv = mTempOutStream->Init(mTempFile, PR_WRONLY | PR_CREATE_FILE | PR_TRUNCATE, 00600, 0);
+  if (NS_FAILED(rv)) return rv;
 
-  if (!mTempOutStream->is_open())
-    return NS_ERROR_FAILURE;
 
   return NS_OK;
 }
@@ -367,8 +378,9 @@ nsIPCBuffer::WriteTempOutStream(const char* buf, PRUint32 count)
   if (!count)
     return NS_OK;
 
-  PRInt32 status = mTempOutStream->write(buf, count);
-  if (status < int(count))
+  PRUint32 writeCount;
+  nsresult rv = mTempOutStream->Write(buf, count, &writeCount);
+  if (NS_FAILED(rv) || (writeCount != count))
     return NS_ERROR_FAILURE;
 
   return NS_OK;
@@ -382,12 +394,13 @@ nsIPCBuffer::CloseTempOutStream()
   DEBUG_LOG(("nsIPCBuffer::CloseTempOutStream: \n"));
 
   if (mTempOutStream) {
-    if (NS_FAILED(mTempOutStream->flush()) || mTempOutStream->failed()) {
+    if (NS_FAILED(mTempOutStream->Flush())) {
       rv = NS_ERROR_FAILURE;
     }
 
-    mTempOutStream->close();
-    delete mTempOutStream;
+    if (NS_FAILED(mTempOutStream->Close())) {
+      rv = NS_ERROR_FAILURE;
+    }
     mTempOutStream = nsnull;
   }
 
@@ -397,9 +410,11 @@ nsIPCBuffer::CloseTempOutStream()
 NS_IMETHODIMP
 nsIPCBuffer::OpenTempInStream()
 {
+  nsresult rv;
+
   DEBUG_LOG(("nsIPCBuffer::OpenTempInStream: \n"));
 
-  if (!mTempFileSpec)
+  if (!mTempFile)
     return NS_ERROR_FAILURE;
 
   if (mTempOutStream) {
@@ -407,10 +422,11 @@ nsIPCBuffer::OpenTempInStream()
     return NS_ERROR_FAILURE;
   }
 
-  mTempInStream = new nsInputFileStream(*mTempFileSpec);
+  mTempInStream  = do_CreateInstance("@mozilla.org/network/file-input-stream;1", &rv);
+  if (NS_FAILED(rv)) return rv;
 
-  if (!mTempInStream->is_open())
-    return NS_ERROR_FAILURE;
+  rv = mTempInStream->Init(mTempFile, PR_RDONLY, 00600, 0);
+  if (NS_FAILED(rv)) return rv;
 
   return NS_OK;
 }
@@ -420,14 +436,15 @@ NS_IMETHODIMP
 nsIPCBuffer::CloseTempInStream()
 {
   DEBUG_LOG(("nsIPCBuffer::CloseTempInStream: \n"));
+  nsresult rv = NS_OK;
 
   if (mTempInStream) {
-    mTempInStream->close();
-    delete mTempInStream;
+    rv = mTempInStream->Close();
+    //delete mTempInStream;
     mTempInStream = nsnull;
   }
 
-  return NS_OK;
+  return rv;
 }
 
 
@@ -447,14 +464,18 @@ nsIPCBuffer::RemoveTempFile()
     CloseTempInStream();
   }
 
-  if (mTempFileSpec) {
+  if (mTempFile) {
+    // delete temp file
+    nsCAutoString nativePath;
+    mTempFile->GetNativePath(nativePath);
     DEBUG_LOG(("nsIPCBuffer::RemoveTempFile: Removing %s\n",
-                mTempFileSpec->GetNativePathCString()));
+                nativePath.get()));
 
-    mTempFileSpec->Delete(PR_FALSE);
+    if (NS_FAILED(mTempFile->Remove(PR_FALSE))) {
+      return NS_ERROR_FAILURE;
+    }
 
-    delete mTempFileSpec;
-    mTempFileSpec = nsnull;
+    mTempFile = nsnull;
   }
 
   return NS_OK;
@@ -869,6 +890,8 @@ nsIPCBuffer::Read(char* buf, PRUint32 count,
 {
   DEBUG_LOG(("nsIPCBuffer::Read: %d\n", count));
 
+  nsresult rv;
+
   if (!buf || !readCount)
     return NS_ERROR_NULL_POINTER;
 
@@ -879,8 +902,10 @@ nsIPCBuffer::Read(char* buf, PRUint32 count,
 
   if (readyCount) {
     if (mTempInStream) {
-      *readCount = mTempInStream->read(buf, readyCount);
-
+      rv = mTempInStream->Read((char *)buf, readyCount, readCount);
+      if (NS_FAILED(rv)) {
+        return rv;
+      }
     } else {
       memcpy(buf, mByteBuf.get()+mStreamOffset, readyCount);
       *readCount = readyCount;
@@ -934,7 +959,8 @@ nsIPCBuffer::ReadSegments(nsWriteSegmentFun writer,
 
     while ((count > 0) && (mStreamOffset < mByteCount)) {
       avail = (count < kCharMax) ? count : kCharMax;
-      readyCount = mTempInStream->read((char *) buf, avail);
+      rv = mTempInStream->Read((char *) buf, avail, &readyCount);
+      if (NS_FAILED(rv)) { return rv; }
 
       if (!readyCount) {
         ERROR_LOG(("nsIPCBuffer::ReadSegments: Error in reading from TempInputStream\n"));
